Welcome to ClientVPS Mirrors

Help for package RCppAD

Package {RCppAD}


Type: Package
Title: 'CppAD' C++ Header Files for Automatic Differentiation
Version: 1.20260000.0
Maintainer: Patrick Brown <patrick.borgnine@gmail.com>
Description: Provides the 'CppAD' C++ header library for automatic differentiation, for use by R packages via LinkingTo. Headers are vendored with CRAN-safe defaults and R-safe error handling that does not call std::cerr or std::exit. The two final components of the version number are the 'CppAD' release number.
License: GPL-2 | GPL-3 [expanded from: GPL (≥ 2)]
URL: https://github.com/eborgnine/adlaplace/
Depends: R (≥ 3.5.0)
NeedsCompilation: no
Encoding: UTF-8
Config/roxygen2/version: 8.0.0
RoxygenNote: 7.3.3
Packaged: 2026-07-29 22:04:17 UTC; patrick
Author: Patrick Brown [aut, cre, cph], Bradley M. Bell [aut, cph] (CppAD author), COIN-OR Foundation [cph] (CppAD)
Repository: CRAN
Date/Publication: 2026-08-07 16:10:22 UTC

CppAD C++ Header Files for Automatic Differentiation

Description

Provides the CppAD C++ header library for automatic differentiation, for use by R packages via LinkingTo: RCppAD.

Details

After depending on this package, include CppAD from C++ with #include <cppad/cppad.hpp>.

Headers are vendored with optional backends (ColPack, Eigen ADOLC, IPOPT) disabled. The error handler uses REprintf / Rf_error instead of std::cerr / std::exit.

Author(s)

Patrick Brown patrick.borgnine@gmail.com (package packaging); Bradley M. Bell (CppAD)

Need a high-speed mirror for your open-source project?
Contact our mirror admin team at info@clientvps.com.

This archive is provided as a free public service to the community.
Proudly supported by infrastructure from VPSPulse , RxServers , BuyNumber , UnitVPS , OffshoreName and secure payment technology by ArionPay.