Package 'RCppAD'

Title: CppAD C++ Header Files for Automatic Differentiation
Description: Provides the CppAD C++ header library for automatic differentiation, for use by R packages via LinkingTo. Headers are vendored with CRAN-safe defaults (optional backends such as ColPack disabled) and R-safe error handling that does not call std::cerr or std::exit.
Authors: Patrick Brown [aut, cre], Bradley M. Bell [aut, cph] (CppAD author), COIN-OR Foundation [cph] (CppAD)
Maintainer: Patrick Brown <[email protected]>
License: file LICENSE
Version: 20260000.0-1
Built: 2026-07-17 20:34:14 UTC
Source: https://github.com/eborgnine/adlaplace

Help Index


CppAD C++ Header Files for Automatic Differentiation

Description

Provides the CppAD C++ header library for automatic differentiation, for use by R packages via LinkingTo: RCppAD.

Details

After depending on this package, include CppAD from C++ with #include <cppad/cppad.hpp>.

Headers are vendored with optional backends (ColPack, Eigen ADOLC, IPOPT) disabled. The error handler uses REprintf / Rf_error instead of std::cerr / std::exit.

Author(s)

EPL-2.0 | GPL (>= 2)